/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { BaseApiCore, constructHeaders, executeHttpCall, Request, Response } from '@managed-api/commons-core';
import { constructUploadFilePayload, createMutation, createQuery, errorMessageBuilder } from './common';
import { customErrorHandlers, errorStrategyBuilderConstructor } from './errorStrategy';
;
export class MondayApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Board = new BoardGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Item = new ItemGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Me = new MeGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.User = new UserGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.File = new FileGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Column = new ColumnGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Notification = new NotificationGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Workspace = new WorkspaceGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Folder = new FolderGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Update = new UpdateGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Team = new TeamGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.ItemsPage = new ItemsPageGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Doc = new DocGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Tag = new TagGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Version = new VersionGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Webhook = new WebhookGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Board, this.Item, this.Me, this.User, this.File, this.Column, this.Notification, this.Workspace, this.Folder, this.Update, this.Team, this.ItemsPage, this.Doc, this.Tag, this.Version, this.Webhook);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options) !== null && _a !== void 0 ? _a : {},
            errorStrategy
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Board, Item, Me, User, File, Column, Notification, Workspace, Folder, Update, Team, ItemsPage, Doc, Tag, Version, Webhook) {
        this.Board = Board;
        this.Item = Item;
        this.Me = Me;
        this.User = User;
        this.File = File;
        this.Column = Column;
        this.Notification = Notification;
        this.Workspace = Workspace;
        this.Folder = Folder;
        this.Update = Update;
        this.Team = Team;
        this.ItemsPage = ItemsPage;
        this.Doc = Doc;
        this.Tag = Tag;
        this.Version = Version;
        this.Webhook = Webhook;
    }
    /**
     * The create_column mutation allows you to create a new column on a board within the account via the API.
     * The create_column mutation also allows you to create a new status or dropdown column with custom labels via the API.
     * Alternative usage: Column.createColumn
     * Documentation: https://developer.monday.com/api-reference/docs/columns#create-a-column
     * @param options Request options.
     */
    async createColumn(options) {
        return this.Column.createColumn(options);
    }
    /**
     * The change_column_value mutation allows you to change the value of a column in a specific item.
     * Alternative usage: Column.changeColumnValue
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-column-value
     * @param options Request options.
     */
    async changeColumnValue(options) {
        return this.Column.changeColumnValue(options);
    }
    /**
     * The change_column_value mutation allows you to change the value of a column in a specific item with a string value.
     * Alternative usage: Column.changeSimpleColumnValue
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-simple-column-value
     * @param options Request options.
     */
    async changeSimpleColumnValue(options) {
        return this.Column.changeSimpleColumnValue(options);
    }
    /**
     * The change_multiple_column_values mutation allows you to change multiple column values of a specific item.
     * Alternative usage: Column.changeMultipleColumnValues
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-multiple-column-values
     * @param options Request options.
     */
    async changeMultipleColumnValues(options) {
        return this.Column.changeMultipleColumnValues(options);
    }
    /**
     * The change_column_title mutation allows you to change the title of an existing column via the API.
     * Alternative usage: Column.changeColumnTitle
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-column-title
     * @param options Request options.
     */
    async changeColumnTitle(options) {
        return this.Column.changeColumnTitle(options);
    }
    /**
     * The change_column_metadata mutation allows you to update the metadata of an existing column.
     * Currently, we support updating both the title and description.
     * Alternative usage: Column.changeColumnMetadata
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-column-metadata
     * @param options Request options.
     */
    async changeColumnMetadata(options) {
        return this.Column.changeColumnMetadata(options);
    }
    /**
     * The delete_column mutation allows you to delete a single column from a board via the API.
     * Alternative usage: Column.deleteColumn
     * Documentation: https://developer.monday.com/api-reference/docs/columns#delete-a-column
     * @param options Request options.
     */
    async deleteColumn(options) {
        return this.Column.deleteColumn(options);
    }
    /**
     * Querying boards will return metadata about one or a collection of boards. This method accepts various arguments and returns an array.
     * Alternative usage: Board.getBoards
     * Documentation: https://developer.monday.com/api-reference/docs/boards#queries
     * @param options Request options.
     */
    async getBoards(options) {
        return this.Board.getBoards(options);
    }
    /**
     * The create_board mutation allows you to create a new board via the API.
     * You can also specify what fields to query back from the new board when you run the mutation.
     * Please note that the user that creates the board via the API will automatically be added as the board's owner when creating a private or shareable board or if the board_owners_ids argument is missing.
     * Alternative usage: Board.createBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#create-a-board
     * @param options Request options.
     */
    async createBoard(options) {
        return this.Board.createBoard(options);
    }
    /**
     * The duplicate_board mutation allows you to duplicate a board with all of its items and groups to a specific workspace or folder of your choice via the API.
     * Alternative usage: Board.duplicateBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#duplicate-a-board
     * @param options Request options.
     */
    async duplicateBoard(options) {
        return this.Board.duplicateBoard(options);
    }
    /**
     * The update_board mutation allows you to update a board via the API.
     * Alternative usage: Board.updateBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#update-a-board
     * @param options Request options.
     */
    async updateBoard(options) {
        return this.Board.updateBoard(options);
    }
    /**
     * The archive_board mutation allows you to archive a board via the API. You can also specify what fields to query back from the archived board when you run the mutation.
     * Alternative usage: Board.archiveBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#archive-a-board
     * @param options Request options.
     */
    async archiveBoard(options) {
        return this.Board.archiveBoard(options);
    }
    /**
     * The delete_board mutation allows you to delete a board via the API. You can also specify what fields to query back from the deleted board when you run the mutation.
     * Alternative usage: Board.deleteBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#delete-a-board
     * @param options Request options.
     */
    async deleteBoard(options) {
        return this.Board.deleteBoard(options);
    }
    /**
     * The delete_subscribers_from_board mutation allows you to delete subscribers from a board via the API. You can also specify what fields to query back from the subscribers you delete from the board when you run the mutation.
     * Alternative usage: Board.deleteSubscribersFromBoard
     * Documentation: https://developer.monday.com/api-reference/docs/boards#delete-subscribers-from-a-board
     * @param options Request options.
     */
    async deleteSubscribersFromBoard(options) {
        return this.Board.deleteSubscribersFromBoard(options);
    }
    /**
     * Querying items_page will return items filtered by the specified criteria. This method accepts various arguments and returns an object.
     * Alternative usage: Board.ItemsPage.getItemsPage
     * Documentation: https://developer.monday.com/api-reference/docs/items_page#queries
     * @param options Request options.
     */
    async getItemsPage(options) {
        return this.Board.ItemsPage.getItemsPage(options);
    }
    /**
     * Querying next_items_page will return the next set of items that correspond with the provided cursor. This method accepts various arguments and returns an object.
     * Alternative usage: ItemsPage.getNextItemsPage
     * Documentation: https://developer.monday.com/api-reference/docs/items_page#cursor-based-pagination-using-next_items_page
     * @param options Request options.
     */
    async getNextItemsPage(options) {
        return this.ItemsPage.getNextItemsPage(options);
    }
    /**
     * Querying items_page_by_column_values will search for items based on predefined column values and return metadata about these specific items. This method accepts various arguments and returns an array.
     * Alternative usage: ItemsPage.getItemsPageByColumnValues
     * Documentation: https://developer.monday.com/api-reference/docs/items-page-by-column-values
     * @param options Request options.
     */
    async getItemsPageByColumnValues(options) {
        return this.ItemsPage.getItemsPageByColumnValues(options);
    }
    /**
     * Querying views will return a collection of board views from a specific board. This method accepts various arguments and returns an array.
     * You can only query views by nesting it within a boards query, so it can't be used at the root.
     * Alternative usage: Board.View.getViews
     * Documentation: https://developer.monday.com/api-reference/docs/board-view-queries#queries
     * @param options Request options.
     */
    async getBoardViews(options) {
        return this.Board.View.getViews(options);
    }
    /**
     * Querying groups will return metadata about one or a collection of groups on a specific board. This method accepts one argument and returns an array.	 *
     * You can only query groups by nesting it within another query, so it can't be used at the root.
     * Alternative usage: Board.Group.getGroups
     * Documentation: https://developer.monday.com/api-reference/docs/groups#queries
     * @param options Request options.
     */
    async getBoardGroups(options) {
        return this.Board.Group.getGroups(options);
    }
    /**
     * The create_group mutation allows you to create a new empty group via the API. You can also specify what fields to query back from the new group when you run the mutation.
     * Alternative usage: Board.Group.createGroup
     * Documentation: https://developer.monday.com/api-reference/docs/groups#create-a-group
     * @param options
     */
    async createGroup(options) {
        return this.Board.Group.createGroup(options);
    }
    /**
     * The update_group mutation allows you to update an existing group via the API. You can also specify what fields to query back from the updated group when you run the mutation.
     * Alternative usage: Board.Group.updateGroup
     * Documentation: https://developer.monday.com/api-reference/docs/groups#update-a-group
     * @param options
     */
    async updateGroup(options) {
        return this.Board.Group.updateGroup(options);
    }
    /**
     * The duplicate_group mutation allows you to duplicate a group with all of its items via the API. You can also specify what fields to query back from the duplicated group when you run the mutation.
     * Alternative usage: Board.Group.duplicateGroup
     * Documentation: https://developer.monday.com/api-reference/docs/groups#duplicate-group
     * (!) Mutation-specific rate limit:
     * The duplicate_group mutation has an additional rate limit of 40 mutations per minute. If you exceed this limit, you will receive a response with a 429 status code, and the following error message: "Call limit exceeded for DuplicateGroup".
     * @param options
     */
    async duplicateGroup(options) {
        return this.Board.Group.duplicateGroup(options);
    }
    /**
     * The archive_group mutation allows you to archive a group with all of its items via the API. You can also specify what fields to query back from the archived group when you run the mutation.
     * Alternative usage: Board.Group.archiveGroup
     * Documentation: https://developer.monday.com/api-reference/docs/groups#archive-a-group
     * @param options
     */
    async archiveGroup(options) {
        return this.Board.Group.archiveGroup(options);
    }
    /**
     * The delete_group mutation allows you to delete a group with all of its items via the API. You can also specify what fields to query back from the deleted group when you run the mutation.
     * Alternative usage: Board.Group.deleteGroup
     * Documentation: https://developer.monday.com/api-reference/docs/groups#delete-a-group
     * @param options
     */
    async deleteGroup(options) {
        return this.Board.Group.deleteGroup(options);
    }
    /**
     * Querying items will return metadata about one or a collection of items. This method accepts various arguments and returns an array.
     * Alternative usage: Item.getItems
     * Documentation: https://developer.monday.com/api-reference/docs/items#queries
     * @param options Request options.
     */
    async getItems(options) {
        return this.Item.getItems(options);
    }
    /**
     * The create_item mutation allows you to create a new item via the API. You can also specify what fields to query back from the new item when you run the mutation.
     * Alternative usage: Item.createItem
     * Documentation: https://developer.monday.com/api-reference/docs/items#create-an-item
     * @param options Request options.
     */
    async createItem(options) {
        return this.Item.createItem(options);
    }
    /**
     * The duplicate_item mutation allows you to duplicate a single item via the API. You can also specify what fields to query back from the duplicated item when you run the mutation.
     * Alternative usage: Item.duplicateItem
     * Documentation: https://developer.monday.com/api-reference/docs/items#duplicate-an-item
     * @param options Request options.
     */
    async duplicateItem(options) {
        return this.Item.duplicateItem(options);
    }
    /**
     * The move_item_to_group mutation allows you to move an item between groups on the same board via the API. You can also specify what fields to query back from the item when you run the mutation.
     * Alternative usage: Item.moveItemToGroup
     * Documentation: https://developer.monday.com/api-reference/docs/items#move-item-to-group
     * @param options Request options.
     */
    async moveItemToGroup(options) {
        return this.Item.moveItemToGroup(options);
    }
    /**
     * The move_item_to_board mutation allows you to move an item to another board via the API. You can also specify what fields to query back from the item moved when you run the mutation.
     * Alternative usage: Item.moveItemToBoard
     * Documentation: https://developer.monday.com/api-reference/docs/items#move-item-to-board
     * @param options Request options.
     */
    async moveItemToBoard(options) {
        return this.Item.moveItemToBoard(options);
    }
    /**
     * The archive_item mutation allows you to archive a single item via the API. You can also specify what fields to query back from the archived item when you run the mutation.
     * Alternative usage: Item.archiveItem
     * Documentation: https://developer.monday.com/api-reference/docs/items#archive-an-item
     * @param options Request options.
     */
    async archiveItem(options) {
        return this.Item.archiveItem(options);
    }
    /**
     * The delete_item mutation allows you to delete a single item via the API. You can also specify what fields to query back from the deleted item when you run the mutation.
     * Alternative usage: Item.deleteItem
     * Documentation: https://developer.monday.com/api-reference/docs/items#delete-an-item
     * @param options Request options.
     */
    async deleteItem(options) {
        return this.Item.deleteItem(options);
    }
    /**
     * The clear_item_updates mutation allows you to clear all updates on a specific item, including replies and likes. You can also specify what fields to query back from the item when you run the mutation.
     * Alternative usage: Item.clearUpdates
     * Documentation: https://developer.monday.com/api-reference/docs/items#clear-an-items-updates
     * @param options Request options.
     */
    async clearItemUpdates(options) {
        return this.Item.clearUpdates(options);
    }
    /**
     * Querying subitems will return metadata about one or a collection of subitems. This method does not accept any arguments and returns an array.
     * You can only query subitems by nesting it within another query, so it can't be used at the root.
     * Alternative usage: Item.Subitem.getSubitems
     * Documentation: https://developer.monday.com/api-reference/docs/subitems#queries
     * @param options Request options.
     */
    async getSubitems(options) {
        return this.Item.Subitem.getSubitems(options);
    }
    /**
     * The create_subitem mutation allows you to create a new subitem via the API. You can also specify what fields to query back from the new subitem when you run the mutation.
     * Alternative usage: Item.Subitem.createSubitem
     * Documentation: https://developer.monday.com/api-reference/docs/subitems#create-a-subitem
     * @param options Request options.
     */
    async createSubitem(options) {
        return this.Item.Subitem.createSubitem(options);
    }
    /**
     * Querying me will return metadata about the user whose API key is being used. This method does not accept any arguments and returns an object.
     * You can only query me directly at the root, so it can't be nested within another query.
     * Alternative usage: Me.getUserDetails
     * Documentation: https://developer.monday.com/api-reference/docs/me#queries
     * @param options Request options.
     */
    async getUserDetails(options) {
        return this.Me.getUserDetails(options);
    }
    /**
     * Querying users will return metadata about one or multiple users. This method accepts various arguments and returns an array.
     * Alternative usage: User.getUsers
     * Documentation: https://developer.monday.com/api-reference/docs/users#queries
     * @param options Request options.
     */
    async getUsers(options) {
        return this.User.getUsers(options);
    }
    /**
     * The add_users_to_board mutation allows you to add users to a board via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Alternative usage: User.addUsersToBoard
     * Documentation: https://developer.monday.com/api-reference/docs/users#add-users-to-a-board
     * @param options Request options.
     */
    async addUsersToBoard(options) {
        return this.User.addUsersToBoard(options);
    }
    /**
     * The add_users_to_workspace mutation allows you to add users to a workspace via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Alternative usage: User.addUsersToWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/users#add-users-to-a-workspace
     * @param options Request options.
     */
    async addUsersToWorkspace(options) {
        return this.User.addUsersToWorkspace(options);
    }
    /**
     * The delete_users_from_workspace mutation allows you to delete users from a workspace via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Alternative usage: User.deleteUsersFromWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/users#delete-users-from-a-workspace
     * @param options Request options.
     */
    async deleteUsersFromWorkspace(options) {
        return this.User.deleteUsersFromWorkspace(options);
    }
    /**
     * Querying assets will return one or a collection of assets. This method accepts various arguments and returns an array.
     * Alternative usage: File.getAssets
     * Documentation: https://developer.monday.com/api-reference/docs/files#queries
     * @param options Request options.
     */
    async getAssets(options) {
        return this.File.getAssets(options);
    }
    /**
     * The add_file_to_update mutation allows you to add a file to an update via the API. You can also specify what fields to query back when you run the mutation. Please note that the file will be added to the bottom of the update.
     * Alternative usage: File.addFileToUpdate
     * Documentation: https://developer.monday.com/api-reference/docs/files#add-a-file-to-an-update
     * @param options Request options.
     */
    async addFileToUpdate(options) {
        return this.File.addFileToUpdate(options);
    }
    /**
     * The add_file_to_column mutation will add a file to the file column of a specific item. You can also specify what fields to query back when you run the mutation.
     * Alternative usage: File.addFileToColumn
     * Documentation: https://developer.monday.com/api-reference/docs/files#add-file-to-the-file-column
     * @param options Request options.
     */
    async addFileToColumn(options) {
        return this.File.addFileToColumn(options);
    }
    /**
     * The create_notification mutation allows you to send a notification to the bell icon via the API. Doing so may also send an email if the recipient's email preferences are set up accordingly.
     * Please note that this mutation only sends the notification; you can't query back the notification ID when running the mutation, as notifications are asynchronous.
     * Alternative usage: Notification.createNotification
     * Documentation: https://developer.monday.com/api-reference/docs/notification#create-a-notification
     * @param options Request options.
     */
    async createNotification(options) {
        return this.Notification.createNotification(options);
    }
    /**
     * Querying workspaces will return metadata about one or a collection of workspaces. This method accepts various arguments and returns an array.
     * Alternative usage: Workspace.getWorkspaces
     * Documentation: https://developer.monday.com/api-reference/docs/workspaces#queries
     * @param options Request options.
     */
    async getWorkspaces(options) {
        return this.Workspace.getWorkspaces(options);
    }
    /**
     * The create_workspace mutation allows you to create a new workspace via the API.
     * You can also specify what fields to query back from the new workspace when you run the mutation.
     * Alternative usage: Workspace.createWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/workspaces#create-a-workspace
     * @param options Request options.
     */
    async createWorkspace(options) {
        return this.Workspace.createWorkspace(options);
    }
    /**
     * The update_workspace mutation allows you to update a workspace via the API.
     * You can also specify what fields to query back from the deleted workspace when you run the mutation.
     * Alternative usage: Workspace.updateWorkspace
     * Documentation: https://developer.monday.com/api-reference/reference/workspaces#update-a-workspace
     * @param options Request options.
     */
    async updateWorkspace(options) {
        return this.Workspace.updateWorkspace(options);
    }
    /**
     * The delete_workspace mutation allows you to delete a workspace via the API.
     * You can also specify what fields to query back from the deleted workspace when you run the mutation.
     * Alternative usage: Workspace.deleteWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/workspaces#delete-a-workspace
     * @param options Request options.
     */
    async deleteWorkspace(options) {
        return this.Workspace.deleteWorkspace(options);
    }
    /**
     * Querying updates will return metadata about one or a collection of updates.
     * This method accepts various arguments and returns an array.
     * Alternative usage: Update.getUpdates
     * Documentation: https://developer.monday.com/api-reference/docs/updates#queries
     * @param options Request options.
     */
    async getUpdates(options) {
        return this.Update.getUpdates(options);
    }
    /**
     * The create_update mutation allows you to add an update to an item via the API.
     * You can also specify what fields to query back from the new update when you run the mutation.
     * Alternative usage: Update.createUpdate
     * Documentation: https://developer.monday.com/api-reference/docs/updates#create-an-update
     * @param options Request options.
     */
    async createUpdate(options) {
        return this.Update.createUpdate(options);
    }
    /**
     * The delete_update mutation allows you to delete an item's update via the API.
     * You can also specify what fields to query back from the update when you run the mutation.
     * Alternative usage: Update.deleteUpdate
     * Documentation: https://developer.monday.com/api-reference/docs/updates#delete-an-update
     * @param options Request options.
     */
    async deleteUpdate(options) {
        return this.Update.deleteUpdate(options);
    }
    /**
     * The like_update mutation allows you to like an update via the API.
     * You can also specify what fields to query back from the update when you run the mutation.
     * Alternative usage: Update.likeUpdate
     * Documentation: https://developer.monday.com/api-reference/docs/updates#like-an-update
     * @param options Request options.
     */
    async likeUpdate(options) {
        return this.Update.likeUpdate(options);
    }
    /**
     * Querying teams will return metadata about one or several teams. This method accepts one argument and returns an array.
     * You can query teams directly at the root, or you can nest it within a users query to return the teams a specific user is part of. Please note that nesting your query will increase its complexity.
     * Alternative: Team.getTeam
     * Documentation: https://developer.monday.com/api-reference/docs/teams#queries
     * @param options
     */
    async getTeams(options) {
        return this.Team.getTeams(options);
    }
    /**
     * The add_teams_to_board mutation allows you to add teams to a board via the API. You can also specify what fields to query back when you run the mutation.
     * Alternative: Team.addTeamsToBoard
     * Documentation: https://developer.monday.com/api-reference/docs/teams#add-teams-to-a-board
     * @param options
     */
    async addTeamsToBoard(options) {
        return this.Team.addTeamsToBoard(options);
    }
    /**
     * The add_teams_to_workspace mutation allows you to add teams to a workspace via the API. You can also specify what fields to query back when you run the mutation.
     * Alternative: Team.addTeamsToWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/teams#add-teams-to-a-workspace
     * @param options
     */
    async addTeamsToWorkspace(options) {
        return this.Team.addTeamsToWorkspace(options);
    }
    /**
     * The delete_teams_from_workspace mutation allows you to delete teams from a workspace via the API.
     * You can also specify what fields to query back when you run the mutation.
     * Alternative: Team.deleteTeamsFromWorkspace
     * Documentation: https://developer.monday.com/api-reference/docs/teams#delete-teams-from-a-workspace
     * @param options
     */
    async deleteTeamsFromWorkspace(options) {
        return this.Team.deleteTeamsFromWorkspace(options);
    }
    /**
     * The delete_teams_from_board mutation allows you to delete teams from a board via the API.
     * You can also specify what fields to query back when you run the mutation.
     * Alternative: Team.deleteTeamsFromBoard
     * Documentation: https://developer.monday.com/api-reference/docs/teams#delete-teams-from-a-board
     * @param options
     */
    async deleteTeamsFromBoard(options) {
        return this.Team.deleteTeamsFromBoard(options);
    }
    /**
     * The add_users_to_team mutation allows you to add users to a team via the API. This mutation returns the ChangeTeamMembershipResult type which allows you to specify what fields to query back when you run the mutation.
     * Alternative: Team.addUsersToTeam
     * Documentation: https://developer.monday.com/api-reference/reference/users#add-users-to-a-team
     * @param options
     */
    async addUsersToTeam(options) {
        return this.Team.addUsersToTeam(options);
    }
    /**
     * The remove_users_from_team mutation allows you to remove users from a team via the API. This mutation returns the ChangeTeamMembershipResult type which allows you to specify what fields to query back when you run the mutation.
     * Alternative: Team.removeUsersFromTeam
     * Documentation: https://developer.monday.com/api-reference/reference/users#remove-users-from-a-team
     * @param options
     */
    async removeUsersFromTeam(options) {
        return this.Team.removeUsersFromTeam(options);
    }
    /**
     * Querying docs will return metadata about a collection of docs. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/docs#queries
     * Alternative: Doc.getDocs
     * @param options Request options.
     */
    async getDocs(options) {
        return this.Doc.getDocs(options);
    }
    /**
     * The create_doc mutation allows you to create a new doc in a document column or workspace via the API. You can also specify what fields to query back from the new doc when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/docs#create-a-doc
     * Alternative: Doc.createDoc
     * @param options Request options.
     */
    async createDoc(options) {
        return this.Doc.createDoc(options);
    }
    /**
     * Querying blocks will return metadata about one or a collection of blocks. The method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#queries
     * Alternative: Doc.DocBlock.getDocBlocks
     * @param options Request options.
     */
    async getDocBlocks(options) {
        return this.Doc.DocBlock.getDocBlocks(options);
    }
    /**
     * The create_doc_block mutation allows you to create a new doc block via the API. You can also specify what fields to query back from the new doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#create-document-block
     * Alternative: Doc.DocBlock.createDocBlock
     * @param options Request options.
     */
    async createDocBlock(options) {
        return this.Doc.DocBlock.createDocBlock(options);
    }
    /**
     * The update_doc_block mutation allows you to update a doc block via the API. You can also specify what fields to query back from the updated doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#update-document-block
     * Alternative: Doc.DocBlock.updateDocBlock
     * @param options Request options.
     */
    async updateDocBlock(options) {
        return this.Doc.DocBlock.updateDocBlock(options);
    }
    /**
     * The delete_doc_block mutation allows you to delete a doc block via the API. You can also specify what fields to query back from the deleted doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#delete-document-block
     * Alternative: Doc.DocBlock.deleteDocBlock
     * @param options Request options.
     */
    async deleteDocBlock(options) {
        return this.Doc.DocBlock.deleteDocBlock(options);
    }
    /**
     * Querying tags will return metadata about one or a collection of the account's public tags. Public tags appear on main boards and are accessible to all member
     * and viewer-level users by default, while private tags only appear on private or shareable boards. This method accepts one argument and returns an array.
     * You can query tags directly at the root to return public tags. If you do so and use the ids argument of a private tag, you will get an empty result.
     * To return tags stored on private or shareable boards, you can nest tags within a boards query.
     * Alternative: Tag.getTags
     * Documentation: https://developer.monday.com/api-reference/docs/tags-queries#queries
     * @param options Request options.
     */
    async getTags(options) {
        return this.Tag.getTags(options);
    }
    /**
     * The create_or_get_tag mutation allows you to create new tags or receive their data if they already exist via the API.
     * You can also specify what fields to query back from the tag when you run the mutation.
     * Alternative: Tag.createOrGetTag
     * Documentation: https://developer.monday.com/api-reference/docs/tags-queries#create-or-get-a-tag
     * @param options Request options.
     */
    async createOrGetTag(options) {
        return this.Tag.createOrGetTag(options);
    }
    /**
     * Querying version will return metadata about the API version used to make a request. This method does not accept any arguments and returns an object.
     * Documentation: https://developer.monday.com/api-reference/docs/version#queries
     * Alternative: Version.getVersion
     * @param options Request options.
     */
    async getVersion(options) {
        return this.Version.getVersion(options);
    }
    /**
     * Querying versions will return metadata about all available API versions. This method does not accept any arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/versions#queries
     * Alternative: Version.getVersions
     * @param options Request options.
     */
    async getVersions(options) {
        return this.Version.getVersions(options);
    }
    /**
     * Querying webhooks will return one or a collection of webhooks. This method accepts various arguments and returns an array.
     * You can only query webhooks directly at the root, so it can't be nested within another query.
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#queries
     * Alternative: Webhook.getWebhooks
     * @param options
     */
    async getWebhooks(options) {
        return this.Webhook.getWebhooks(options);
    }
    /**
     * The create_webhook mutation allows you to create a new webhook via the API. You can also specify what fields to query back when you run the mutation.
     * After the mutation runs, a webhook subscription will be created based on a specific event, so the webhook will send data to the subscribed URL every time the event happens on your board.
     *
     * You can add a query param to your webhook URL if you want to differentiate between subitem and main item events.
     * The URL must pass a verification test where we will send a JSON POST body request containing a challenge field.
     * Monday.com expects your provided URL to return the token as a challenge field in your response JSON body to that request.
     *
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#create-a-webhook
     * Alternative: Webhook.createWebhook
     * @param options
     */
    async createWebhook(options) {
        return this.Webhook.createWebhook(options);
    }
    /**
     * The delete_webhook mutation allows you to delete a webhook via the API.
     * You can also specify what fields to query back when you run the mutation.
     * After the mutation runs, it will no longer report events to the URL given.
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#delete-a-webhook
     * Alternative: Webhook.deleteWebhook
     * @param options
     */
    async deleteWebhook(options) {
        return this.Webhook.deleteWebhook(options);
    }
    /**
     * Querying folders will return metadata about one or a collection of folders. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#queries
     * Alternative: Folder.getFolders
     * @param options Request options.
     */
    async getFolders(options) {
        return this.Folder.getFolders(options);
    }
    /**
     * The create_folder mutation allows you to create a new folder in a workspace via the API. You can also specify what fields to query back from the new folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#create-a-folder
     * Alternative: Folder.createFolder
     * @param options Request options.
     */
    async createFolder(options) {
        return this.Folder.createFolder(options);
    }
    /**
     * The update_folder mutation allows you to update a folder's color, name, or parent folder via the API. You can also specify what fields to query back from the updated folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#update-a-folder
     * Alternative: Folder.updateFolder
     * @param options Request options.
     */
    async updateFolder(options) {
        return this.Folder.updateFolder(options);
    }
    /**
     * The delete_folder mutation allows you to delete and folder and all its contents via the API. You can also specify what fields to query back from the deleted folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#delete-a-folder
     * Alternative: Folder.deleteFolder
     * @param options Request options.
     */
    async deleteFolder(options) {
        return this.Folder.deleteFolder(options);
    }
}
class NotificationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * The create_notification mutation allows you to send a notification to the bell icon via the API. Doing so may also send an email if the recipient's email preferences are set up accordingly.
     * Please note that this mutation only sends the notification; you can't query back the notification ID when running the mutation, as notifications are asynchronous.
     * Documentation: https://developer.monday.com/api-reference/docs/notification#create-a-notification
     * @param options Request options.
     */
    async createNotification(options) {
        return await createMutation(options, 'create_notification', this.implementation, this.getGlobalErrorStrategy);
    }
}
class TeamGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * The delete_teams_from_workspace mutation allows you to delete teams from a workspace via the API.
     * You can also specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/teams#delete-teams-from-a-workspace
     * @param options
     */
    async deleteTeamsFromWorkspace(options) {
        return await createMutation(options, 'delete_teams_from_workspace', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_teams_from_board mutation allows you to delete teams from a board via the API.
     * You can also specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/teams#delete-teams-from-a-board
     * @param options
     */
    async deleteTeamsFromBoard(options) {
        return await createMutation(options, 'delete_teams_from_board', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The add_teams_to_workspace mutation allows you to add teams to a workspace via the API. You can also specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/teams#add-teams-to-a-workspace
     * @param options
     */
    async addTeamsToWorkspace(options) {
        return await createMutation(options, 'add_teams_to_workspace', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The add_teams_to_board mutation allows you to add teams to a board via the API. You can also specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/teams#add-teams-to-a-board
     * @param options
     */
    async addTeamsToBoard(options) {
        return await createMutation(options, 'add_teams_to_board', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Querying teams will return metadata about one or several teams. This method accepts one argument and returns an array.
     *
     * You can query teams directly at the root, or you can nest it within a users query to return the teams a specific user is part of. Please note that nesting your query will increase its complexity.
     * Documentation: https://developer.monday.com/api-reference/docs/teams#queries
     * @param options
     */
    async getTeams(options) {
        return await createQuery(options, 'teams', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The add_users_to_team mutation allows you to add users to a team via the API. This mutation returns the ChangeTeamMembershipResult type which allows you to specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/reference/users#add-users-to-a-team
     * @param options
     */
    async addUsersToTeam(options) {
        return await createMutation(options, 'add_users_to_team', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The remove_users_from_team mutation allows you to remove users from a team via the API. This mutation returns the ChangeTeamMembershipResult type which allows you to specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/reference/users#remove-users-from-a-team
     * @param options
     */
    async removeUsersFromTeam(options) {
        return await createMutation(options, 'remove_users_from_team', this.implementation, this.getGlobalErrorStrategy);
    }
}
class BoardGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.View = new BoardViewGroup(implementation, this.getGlobalErrorStrategy);
        this.Group = new BoardGroupGroup(implementation, this.getGlobalErrorStrategy);
        this.ItemsPage = new BoardItemsPageGroup(implementation, this.getGlobalErrorStrategy);
        this.Tag = new BoardTagGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Querying boards will return metadata about one or a collection of boards. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#queries
     * @param options Request options.
     */
    async getBoards(options) {
        return await createQuery(options, 'boards', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The create_board mutation allows you to create a new board via the API.
     * You can also specify what fields to query back from the new board when you run the mutation.
     * Please note that the user that creates the board via the API will automatically be added as the board's owner when creating a private or shareable board or if the board_owners_ids argument is missing.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#create-a-board
     * @param options Request options.
     */
    async createBoard(options) {
        return await createMutation(options, 'create_board', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The duplicate_board mutation allows you to duplicate a board with all of its items and groups to a specific workspace or folder of your choice via the API.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#duplicate-a-board
     * @param options Request options.
     */
    async duplicateBoard(options) {
        return await createMutation(options, 'duplicate_board', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The update_board mutation allows you to update a board via the API.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#update-a-board
     * @param options Request options.
     */
    async updateBoard(options) {
        return await createMutation({ ...options, fields: {} }, 'update_board', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The archive_board mutation allows you to archive a board via the API. You can also specify what fields to query back from the archived board when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#archive-a-board
     * @param options Request options.
     */
    async archiveBoard(options) {
        return await createMutation(options, 'archive_board', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_board mutation allows you to delete a board via the API. You can also specify what fields to query back from the deleted board when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#delete-a-board
     * @param options Request options.
     */
    async deleteBoard(options) {
        return await createMutation(options, 'delete_board', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_subscribers_from_board mutation allows you to delete subscribers from a board via the API. You can also specify what fields to query back from the subscribers you delete from the board when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/boards#delete-subscribers-from-a-board
     * @param options Request options.
     */
    async deleteSubscribersFromBoard(options) {
        return await createMutation(options, 'delete_subscribers_from_board', this.implementation, this.getGlobalErrorStrategy);
    }
}
class BoardGroupGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * The update_group mutation allows you to update an existing group via the API. You can also specify what fields to query back from the updated group when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#update-a-group
     * @param options
     */
    async updateGroup(options) {
        return await createMutation(options, 'update_group', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The duplicate_group mutation allows you to duplicate a group with all of its items via the API. You can also specify what fields to query back from the duplicated group when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#duplicate-group
     * (!) Mutation-specific rate limit:
     * The duplicate_group mutation has an additional rate limit of 40 mutations per minute. If you exceed this limit, you will receive a response with a 429 status code, and the following error message: "Call limit exceeded for DuplicateGroup".
     * @param options
     */
    async duplicateGroup(options) {
        return await createMutation(options, 'duplicate_group', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The archive_group mutation allows you to archive a group with all of its items via the API. You can also specify what fields to query back from the archived group when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#archive-a-group
     * @param options
     */
    async archiveGroup(options) {
        return await createMutation(options, 'archive_group', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_group mutation allows you to delete a group with all of its items via the API. You can also specify what fields to query back from the deleted group when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#delete-a-group
     * @param options
     */
    async deleteGroup(options) {
        return await createMutation(options, 'delete_group', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The create_group mutation allows you to create a new empty group via the API. You can also specify what fields to query back from the new group when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#create-a-group
     * @param options
     */
    async createGroup(options) {
        return await createMutation(options, 'create_group', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Querying groups will return metadata about one or a collection of groups on a specific board. This method accepts one argument and returns an array.	 *
     * You can only query groups by nesting it within another query, so it can't be used at the root.
     * Documentation: https://developer.monday.com/api-reference/docs/groups#queries
     * @param options Request options.
     */
    async getGroups(options) {
        return await createQuery(options, 'boards', this.implementation, this.getGlobalErrorStrategy);
    }
}
class BoardViewGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying views will return a collection of board views from a specific board. This method accepts various arguments and returns an array.
     * You can only query views by nesting it within a boards query, so it can't be used at the root.
     * Documentation: https://developer.monday.com/api-reference/docs/board-view-queries#queries
     * @param options Request options.
     */
    async getViews(options) {
        return await createQuery(options, 'boards', this.implementation, this.getGlobalErrorStrategy);
    }
}
class ItemGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Subitem = new ItemSubitemGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Querying items will return metadata about one or a collection of items. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/items#queries
     * @param options Request options.
     */
    async getItems(options) {
        return await createQuery(options, 'items', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The create_item mutation allows you to create a new item via the API. You can also specify what fields to query back from the new item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#create-an-item
     * @param options Request options.
     */
    async createItem(options) {
        return await createMutation(options, 'create_item', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The duplicate_item mutation allows you to duplicate a single item via the API. You can also specify what fields to query back from the duplicated item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#duplicate-an-item
     * @param options Request options.
     */
    async duplicateItem(options) {
        return await createMutation(options, 'duplicate_item', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The move_item_to_group mutation allows you to move an item between groups on the same board via the API. You can also specify what fields to query back from the item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#move-item-to-group
     * @param options Request options.
     */
    async moveItemToGroup(options) {
        return await createMutation(options, 'move_item_to_group', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The move_item_to_board mutation allows you to move an item to another board via the API. You can also specify what fields to query back from the item moved when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#move-item-to-board
     * @param options Request options.
     */
    async moveItemToBoard(options) {
        return await createMutation(options, 'move_item_to_board', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The archive_item mutation allows you to archive a single item via the API. You can also specify what fields to query back from the archived item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#archive-an-item
     * @param options Request options.
     */
    async archiveItem(options) {
        return await createMutation(options, 'archive_item', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_item mutation allows you to delete a single item via the API. You can also specify what fields to query back from the deleted item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#delete-an-item
     * @param options Request options.
     */
    async deleteItem(options) {
        return await createMutation(options, 'delete_item', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The clear_item_updates mutation allows you to clear all updates on a specific item, including replies and likes. You can also specify what fields to query back from the item when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/items#clear-an-items-updates
     * @param options Request options.
     */
    async clearUpdates(options) {
        return await createMutation(options, 'clear_item_updates', this.implementation, this.getGlobalErrorStrategy);
    }
}
class BoardItemsPageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying items_page will return items filtered by the specified criteria. This method accepts various arguments and returns an object.
     * Documentation: https://developer.monday.com/api-reference/docs/items_page#queries
     * @param options Request options.
     */
    async getItemsPage(options) {
        return await createQuery(options, 'boards', this.implementation, this.getGlobalErrorStrategy);
    }
}
class BoardTagGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying tags will return metadata about one or a collection of the account's public tags. Public tags appear on main boards and are accessible to all member
     * and viewer-level users by default, while private tags only appear on private or shareable boards. This method accepts no arguments and returns an array.
     * You can query tags directly at the root to return public tags. If you do so and use the ids argument of a private tag, you will get an empty result.
     * To return tags stored on private or shareable boards, you can use this managed API, which is nested within a boards query.
     * Documentation: https://developer.monday.com/api-reference/docs/tags-queries#queries
     * @param options Request options.
     */
    async getTags(options) {
        return await createQuery(options, 'boards', this.implementation, this.getGlobalErrorStrategy);
    }
}
class ItemsPageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying next_items_page will return the next set of items that correspond with the provided cursor. This method accepts various arguments and returns an object.
     * Documentation: https://developer.monday.com/api-reference/docs/items_page#cursor-based-pagination-using-next_items_page
     * @param options Request options.
     */
    async getNextItemsPage(options) {
        return await createQuery(options, 'next_items_page', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Querying items_page_by_column_values will search for items based on predefined column values and return metadata about these specific items. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/items-page-by-column-values
     * @param options Request options.
     */
    async getItemsPageByColumnValues(options) {
        return await createQuery(options, 'items_page_by_column_values', this.implementation, this.getGlobalErrorStrategy);
    }
}
class ItemSubitemGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying subitems will return metadata about one or a collection of subitems. This method does not accept any arguments and returns an array.
     * You can only query subitems by nesting it within another query, so it can't be used at the root.
     * Documentation: https://developer.monday.com/api-reference/docs/subitems#queries
     * @param options Request options.
     */
    async getSubitems(options) {
        return await createQuery(options, 'items', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The create_subitem mutation allows you to create a new subitem via the API. You can also specify what fields to query back from the new subitem when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/subitems#create-a-subitem
     * @param options Request options.
     */
    async createSubitem(options) {
        return await createMutation(options, 'create_subitem', this.implementation, this.getGlobalErrorStrategy);
    }
}
class MeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying me will return metadata about the user whose API key is being used. This method does not accept any arguments and returns an object.
     * You can only query me directly at the root, so it can't be nested within another query.
     * Documentation: https://developer.monday.com/api-reference/docs/me#queries
     * @param options Request options.
     */
    async getUserDetails(options) {
        return await createQuery(options, 'me', this.implementation, this.getGlobalErrorStrategy);
    }
}
class UserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying users will return metadata about one or multiple users. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/users#queries
     * @param options Request options.
     */
    async getUsers(options) {
        return await createQuery(options, 'users', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The add_users_to_board mutation allows you to add users to a board via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/users#add-users-to-a-board
     * @param options Request options.
     */
    async addUsersToBoard(options) {
        return await createMutation(options, 'add_users_to_board', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The add_users_to_workspace mutation allows you to add users to a workspace via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/users#add-users-to-a-workspace
     * @param options Request options.
     */
    async addUsersToWorkspace(options) {
        return await createMutation(options, 'add_users_to_workspace', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_users_from_workspace mutation allows you to delete users from a workspace via the API. You can also specify what fields to query back from the user when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/users#delete-users-from-a-workspace
     * @param options Request options.
     */
    async deleteUsersFromWorkspace(options) {
        return await createMutation(options, 'delete_users_from_workspace', this.implementation, this.getGlobalErrorStrategy);
    }
}
class FileGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying assets will return one or a collection of assets. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/files#queries
     * @param options Request options.
     */
    async getAssets(options) {
        return await createQuery(options, 'assets', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The add_file_to_update mutation allows you to add a file to an update via the API. You can also specify what fields to query back when you run the mutation. Please note that the file will be added to the bottom of the update.
     * Documentation: https://developer.monday.com/api-reference/docs/files#add-a-file-to-an-update
     * @param options Request options.
     */
    async addFileToUpdate(options) {
        const { headers, errorStrategy, fields, args, complexity } = options;
        const body = await constructUploadFilePayload('add_file_to_update', this.implementation, args, fields, complexity);
        const request = new Request('POST', '/v2/file', constructHeaders(body, headers), body);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * The add_file_to_column mutation will add a file to the file column of a specific item. You can also specify what fields to query back when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/files#add-file-to-the-file-column
     * @param options Request options.
     */
    async addFileToColumn(options) {
        const { headers, errorStrategy, fields, args, complexity } = options;
        const body = await constructUploadFilePayload('add_file_to_column', this.implementation, args, fields, complexity);
        const request = new Request('POST', '/v2/file', constructHeaders(body, headers), body);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ColumnGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * The create_column mutation allows you to create a new column on a board within the account via the API.
     * The create_column mutation also allows you to create a new status or dropdown column with custom labels via the API.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#create-a-column
     * @param options Request options.
     */
    async createColumn(options) {
        return await createMutation(options, 'create_column', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The change_column_value mutation allows you to change the value of a column in a specific item.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-column-value
     * @param options Request options.
     */
    async changeColumnValue(options) {
        return await createMutation(options, 'change_column_value', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The change_column_value mutation allows you to change the value of a column in a specific item with a string value.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-simple-column-value
     * @param options Request options.
     */
    async changeSimpleColumnValue(options) {
        return await createMutation(options, 'change_simple_column_value', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The change_multiple_column_values mutation allows you to change multiple column values of a specific item.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-multiple-column-values
     * @param options Request options.
     */
    async changeMultipleColumnValues(options) {
        return await createMutation(options, 'change_multiple_column_values', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The change_column_title mutation allows you to change the title of an existing column via the API.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-a-column-title
     * @param options Request options.
     */
    async changeColumnTitle(options) {
        return await createMutation(options, 'change_column_title', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The change_column_metadata mutation allows you to update the metadata of an existing column.
     * Currently, we support updating both the title and description.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#change-column-metadata
     * @param options Request options.
     */
    async changeColumnMetadata(options) {
        return await createMutation(options, 'change_column_metadata', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_column mutation allows you to delete a single column from a board via the API.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#delete-a-column
     * @param options Request options.
     */
    async deleteColumn(options) {
        return await createMutation(options, 'delete_column', this.implementation, this.getGlobalErrorStrategy);
    }
}
class WorkspaceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying workspaces will return metadata about one or a collection of workspaces.
     * This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/workspaces#queries
     * @param options Request options.
     */
    async getWorkspaces(options) {
        return await createQuery(options, 'workspaces', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The create_workspace mutation allows you to create a new workspace via the API.
     * You can also specify what fields to query back from the new workspace when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/workspaces#create-a-workspace
     * @param options Request options.
     */
    async createWorkspace(options) {
        return await createMutation(options, 'create_workspace', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The update_workspace mutation allows you to update a workspace via the API.
     * You can also specify what fields to query back from the deleted workspace when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/reference/workspaces#update-a-workspace
     * @param options Request options.
     */
    async updateWorkspace(options) {
        return await createMutation(options, 'update_workspace', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_workspace mutation allows you to delete a workspace via the API.
     * You can also specify what fields to query back from the deleted workspace when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/columns#delete-a-column
     * @param options Request options.
     */
    async deleteWorkspace(options) {
        return await createMutation(options, 'delete_workspace', this.implementation, this.getGlobalErrorStrategy);
    }
}
class FolderGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying folders will return metadata about one or a collection of folders. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#queries
     * @param options Request options.
     */
    async getFolders(options) {
        return await createQuery(options, 'folders', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The create_folder mutation allows you to create a new folder in a workspace via the API. You can also specify what fields to query back from the new folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#create-a-folder
     * @param options Request options.
     */
    async createFolder(options) {
        return await createMutation(options, 'create_folder', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The update_folder mutation allows you to update a folder's color, name, or parent folder via the API. You can also specify what fields to query back from the updated folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#update-a-folder
     * @param options Request options.
     */
    async updateFolder(options) {
        return await createMutation(options, 'update_folder', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_folder mutation allows you to delete and folder and all its contents via the API. You can also specify what fields to query back from the deleted folder when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/folders#delete-a-folder
     * @param options Request options.
     */
    async deleteFolder(options) {
        return await createMutation(options, 'delete_folder', this.implementation, this.getGlobalErrorStrategy);
    }
}
class UpdateGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying updates will return metadata about one or a collection of updates.
     * This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/updates#queries
     * @param options Request options.
     */
    async getUpdates(options) {
        return await createQuery(options, 'updates', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The create_update mutation allows you to add an update to an item via the API.
     * You can also specify what fields to query back from the new update when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/updates#create-an-update
     * @param options Request options.
     */
    async createUpdate(options) {
        return await createMutation(options, 'create_update', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_update mutation allows you to delete an item's update via the API.
     * You can also specify what fields to query back from the update when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/updates#delete-an-update
     * @param options Request options.
     */
    async deleteUpdate(options) {
        return await createMutation(options, 'delete_update', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The like_update mutation allows you to like an update via the API.
     * You can also specify what fields to query back from the update when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/updates#like-an-update
     * @param options Request options.
     */
    async likeUpdate(options) {
        return await createMutation(options, 'like_update', this.implementation, this.getGlobalErrorStrategy);
    }
}
class DocGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.DocBlock = new DocBlockGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Querying docs will return metadata about a collection of docs. This method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/docs#queries
     * @param options Request options.
     */
    async getDocs(options) {
        return await createQuery(options, 'docs', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The create_doc mutation allows you to create a new doc in a document column or workspace via the API. You can also specify what fields to query back from the new doc when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/docs#create-a-doc
     * @param options Request options.
     */
    async createDoc(options) {
        return await createMutation(options, 'create_doc', this.implementation, this.getGlobalErrorStrategy);
    }
}
class DocBlockGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying blocks will return metadata about one or a collection of blocks. The method accepts various arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#queries
     * @param options Request options.
     */
    async getDocBlocks(options) {
        return await createQuery(options, 'docs', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The create_doc_block mutation allows you to create a new doc block via the API. You can also specify what fields to query back from the new doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#create-document-block
     * @param options Request options.
     */
    async createDocBlock(options) {
        return await createMutation(options, 'create_doc_block', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The update_doc_block mutation allows you to update a doc block via the API. You can also specify what fields to query back from the updated doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#update-document-block
     * @param options Request options.
     */
    async updateDocBlock(options) {
        return await createMutation(options, 'update_doc_block', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_doc_block mutation allows you to delete a doc block via the API. You can also specify what fields to query back from the deleted doc block when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/blocks#delete-document-block
     * @param options Request options.
     */
    async deleteDocBlock(options) {
        return await createMutation(options, 'delete_doc_block', this.implementation, this.getGlobalErrorStrategy);
    }
}
class TagGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying tags will return metadata about one or a collection of the account's public tags. Public tags appear on main boards and are accessible to all member
     * and viewer-level users by default, while private tags only appear on private or shareable boards. This method accepts one argument and returns an array.
     * You can query tags directly at the root to return public tags. If you do so and use the ids argument of a private tag, you will get an empty result.
     * To return tags stored on private or shareable boards, you can nest tags within a boards query.
     * Documentation: https://developer.monday.com/api-reference/docs/tags-queries#queries
     * @param options Request options.
     */
    async getTags(options) {
        return await createQuery(options, 'tags', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The create_or_get_tag mutation allows you to create new tags or receive their data if they already exist via the API.
     * You can also specify what fields to query back from the tag when you run the mutation.
     * Documentation: https://developer.monday.com/api-reference/docs/tags-queries#create-or-get-a-tag
     * @param options Request options.
     */
    async createOrGetTag(options) {
        return await createMutation(options, 'create_or_get_tag', this.implementation, this.getGlobalErrorStrategy);
    }
}
class VersionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying version will return metadata about the API version used to make a request. This method does not accept any arguments and returns an object.
     * Documentation: https://developer.monday.com/api-reference/docs/version#queries
     * @param options Request options.
     */
    async getVersion(options) {
        return await createQuery(options, 'version', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Querying versions will return metadata about all available API versions. This method does not accept any arguments and returns an array.
     * Documentation: https://developer.monday.com/api-reference/docs/versions#queries
     * @param options Request options.
     */
    async getVersions(options) {
        return await createQuery(options, 'versions', this.implementation, this.getGlobalErrorStrategy);
    }
}
class WebhookGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Querying webhooks will return one or a collection of webhooks. This method accepts various arguments and returns an array.
     * You can only query webhooks directly at the root, so it can't be nested within another query.
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#queries
     * @param options
     */
    async getWebhooks(options) {
        return await createQuery(options, 'webhooks', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The create_webhook mutation allows you to create a new webhook via the API. You can also specify what fields to query back when you run the mutation.
     * After the mutation runs, a webhook subscription will be created based on a specific event, so the webhook will send data to the subscribed URL every time the event happens on your board.
     *
     * You can add a query param to your webhook URL if you want to differentiate between subitem and main item events.
     * The URL must pass a verification test where we will send a JSON POST body request containing a challenge field.
     * Monday.com expects your provided URL to return the token as a challenge field in your response JSON body to that request.
     *
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#create-a-webhook
     * @param options
     */
    async createWebhook(options) {
        return await createMutation(options, 'create_webhook', this.implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The delete_webhook mutation allows you to delete a webhook via the API.
     * You can also specify what fields to query back when you run the mutation.
     * After the mutation runs, it will no longer report events to the URL given.
     * Documentation: https://developer.monday.com/api-reference/docs/webhooks#delete-a-webhook
     * @param options
     */
    async deleteWebhook(options) {
        return await createMutation(options, 'delete_webhook', this.implementation, this.getGlobalErrorStrategy);
    }
}
